
#ifndef KDEPIMDBUSINTERFACES_EXPORT_H
#define KDEPIMDBUSINTERFACES_EXPORT_H

#ifdef KDEPIMDBUSINTERFACES_STATIC_DEFINE
#  define KDEPIMDBUSINTERFACES_EXPORT
#  define KDEPIMDBUSINTERFACES_NO_EXPORT
#else
#  ifndef KDEPIMDBUSINTERFACES_EXPORT
#    ifdef KF5KdepimDBusInterfaces_EXPORTS
        /* We are building this library */
#      define KDEPIMDBUSINTERFACES_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KDEPIMDBUSINTERFACES_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KDEPIMDBUSINTERFACES_NO_EXPORT
#    define KDEPIMDBUSINTERFACES_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KDEPIMDBUSINTERFACES_DEPRECATED
#  define KDEPIMDBUSINTERFACES_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KDEPIMDBUSINTERFACES_DEPRECATED_EXPORT
#  define KDEPIMDBUSINTERFACES_DEPRECATED_EXPORT KDEPIMDBUSINTERFACES_EXPORT KDEPIMDBUSINTERFACES_DEPRECATED
#endif

#ifndef KDEPIMDBUSINTERFACES_DEPRECATED_NO_EXPORT
#  define KDEPIMDBUSINTERFACES_DEPRECATED_NO_EXPORT KDEPIMDBUSINTERFACES_NO_EXPORT KDEPIMDBUSINTERFACES_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KDEPIMDBUSINTERFACES_NO_DEPRECATED
#    define KDEPIMDBUSINTERFACES_NO_DEPRECATED
#  endif
#endif

#endif
